@@ -14,6 +14,12 @@ urlpatterns = [
         name='verified_name'
     ),
 
+    url(
+        r'edx_name_affirmation/v1/verified_name/history$',
+        views.VerifiedNameHistoryView.as_view(),
+        name='verified_name_history'
+    ),
+
     url(
         r'edx_name_affirmation/v1/verified_name/config$',
         views.VerifiedNameConfigView.as_view(),
